.. Copyright (C) 2016-2017 Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2016-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.apache`` role allows you to setup and manage the `Apache HTTP Server`__
with version 2.4 and above.

.. __: https://httpd.apache.org/
